bisql.adapter.next-jdbc


->dateclj

(->date value)

Converts common JVM date/time values into java.sql.Date. This is an explicit helper for next.jdbc callers and is not applied automatically.

Converts common JVM date/time values into java.sql.Date.
This is an explicit helper for next.jdbc callers and is not applied automatically.
sourceraw docstring

->timeclj

(->time value)

Converts common JVM date/time values into java.sql.Time. This is an explicit helper for next.jdbc callers and is not applied automatically.

Converts common JVM date/time values into java.sql.Time.
This is an explicit helper for next.jdbc callers and is not applied automatically.
sourceraw docstring

->timestampclj

(->timestamp value)

Converts common JVM date/time values into java.sql.Timestamp. This is an explicit helper for next.jdbc callers and is not applied automatically.

Converts common JVM date/time values into java.sql.Timestamp.
This is an explicit helper for next.jdbc callers and is not applied automatically.
sourceraw docstring

defquerycljmacro

(defquery)
(defquery path)
(defquery path options)

Defines one executable query function per query found in a SQL file or directory.

Defines one executable query function per query found in a SQL file or directory.
sourceraw docstring

exec!clj

(exec! datasource queryish)
(exec! datasource queryish template-params)

Renders and executes a query via next.jdbc. The result cardinality is resolved from :cardinality metadata and must be :one or :many.

Renders and executes a query via next.jdbc.
The result cardinality is resolved from :cardinality metadata and must be :one or :many.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries