(analyze-template template)Analyzes a template and returns declaration metadata plus the declaration-free SQL template.
Analyzes a template and returns declaration metadata plus the declaration-free SQL template.
(compile-renderer parsed-template)Compiles a parsed template into a reusable renderer function.
Compiles a parsed template into a reusable renderer function.
Builds a reusable renderer function from a parsed template via the renderer-plan interpreter.
Builds a reusable renderer function from a parsed template via the renderer-plan interpreter.
(consume-leading-conditional-operator-from-text sql)(emit-renderer-form parsed-template)Emits a reusable renderer function form from a parsed template.
Emits a reusable renderer function form from a parsed template.
(evaluate-renderer parsed-template template-params)Evaluates a parsed template and returns rendered SQL plus bind parameters.
Evaluates a parsed template and returns rendered SQL plus bind parameters.
(evaluate-renderer-plan plan template-params)Evaluates a renderer plan and returns rendered SQL plus bind parameters.
Evaluates a renderer plan and returns rendered SQL plus bind parameters.
(loaded-template query-name
function-name
namespace-suffix
base-path
resource-path
project-relative-path
source-line
sql-template)(parse-template sql)Parses a declaration-free SQL template string into an intermediate representation.
Parses a declaration-free SQL template string into an intermediate representation.
(query-location query-name)(query-location context-query-name declared-query-name)Resolves query-name, function-name, and namespace-suffix from a logical query name.
Resolves query-name, function-name, and namespace-suffix from a logical query name.
(render-compiled-query template renderer template-params)Renders an already analyzed template with a precompiled renderer.
Renders an already analyzed template with a precompiled renderer.
(render-query template template-params)Renders a loaded template into executable SQL plus parameters.
Renders a loaded template into executable SQL plus parameters.
(renderer-plan parsed-template)Builds an execution-oriented renderer plan from a parsed template.
Builds an execution-oriented renderer plan from a parsed template.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |