Clojure only.

bisql.adapter.next-jdbc


defquerycljmacro

(defquery)
(defquery path)
(defquery path options)

Defines one executable query function per query found in a SQL file or directory.

Defines one executable query function per query found in a SQL file or directory.
raw docstring

exec!clj

(exec! datasource queryish)
(exec! datasource queryish template-params)

Renders and executes a query via next.jdbc. The result cardinality is resolved from :cardinality metadata and must be :one or :many.

Renders and executes a query via next.jdbc.
The result cardinality is resolved from :cardinality metadata and must be :one or :many.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries