(defquery)(defquery path)(defquery path options)Defines one executable query function per query found in a SQL file or directory. The default adapter is :next-jdbc.
Defines one executable query function per query found in a SQL file or directory. The default adapter is :next-jdbc.
(defrender)(defrender path)Defines one rendering function per query found under the current query namespace path, or under a relative/absolute path when one is provided.
Defines one rendering function per query found under the current query namespace path, or under a relative/absolute path when one is provided.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |