(load-queries filename)(load-queries filename {:keys [base-path] :or {base-path "sql"}})Loads a SQL file and returns all query templates keyed by query name.
Loads a SQL file and returns all query templates keyed by query name.
(load-queries-from-file relative-path file-path)(load-queries-from-file relative-path
file-path
{:keys [base-path] :or {base-path "sql"}})Loads query templates directly from a filesystem SQL file.
Loads query templates directly from a filesystem SQL file.
(load-query filename)(load-query filename {:keys [base-path] :or {base-path "sql"}})Loads a SQL file and returns a single query template. If the file contains multiple queries, this function throws.
Loads a SQL file and returns a single query template. If the file contains multiple queries, this function throws.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |