bisql.query


ALLclj


analyze-templateclj

(analyze-template template)

Analyzes a template and returns declaration metadata plus the declaration-free SQL template.

Analyzes a template and returns declaration metadata plus the declaration-free SQL template.
raw docstring

defaultclj


load-queriesclj

(load-queries filename)
(load-queries filename {:keys [base-path] :or {base-path "sql"}})

Loads a SQL file and returns all query templates keyed by query name.

Loads a SQL file and returns all query templates keyed by query name.
raw docstring

load-queryclj

(load-query filename)
(load-query filename {:keys [base-path] :or {base-path "sql"}})

Loads a SQL file and returns a single query template. If the file contains multiple queries, this function throws.

Loads a SQL file and returns a single query template.
If the file contains multiple queries, this function throws.
raw docstring

render-queryclj

(render-query template template-params)

Renders a loaded template into executable SQL plus parameters. Initial implementation supports bind variables and collection binding.

Renders a loaded template into executable SQL plus parameters.
Initial implementation supports bind variables and collection binding.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries