(analyze-template template)Analyzes a template and returns declaration metadata plus the declaration-free SQL template.
Analyzes a template and returns declaration metadata plus the declaration-free SQL template.
(load-queries filename)(load-queries filename {:keys [base-path] :or {base-path "sql"}})Loads a SQL file and returns all query templates keyed by query name.
Loads a SQL file and returns all query templates keyed by query name.
(load-query filename)(load-query filename {:keys [base-path] :or {base-path "sql"}})Loads a SQL file and returns a single query template. If the file contains multiple queries, this function throws.
Loads a SQL file and returns a single query template. If the file contains multiple queries, this function throws.
(render-query template template-params)Renders a loaded template into executable SQL plus parameters. Initial implementation supports bind variables and collection binding.
Renders a loaded template into executable SQL plus parameters. Initial implementation supports bind variables and collection binding.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |